API Reference
=============

Клиент
------

.. automodule:: amocrm.client
   :members:

Авторизация
-----------

.. automodule:: amocrm.auth
   :members:

Менеджер (синглтон)
-------------------

.. automodule:: amocrm.manager
   :members:

Исключения
----------

.. automodule:: amocrm.exceptions
   :members:

Ресурсы
-------

Базовый ресурс
~~~~~~~~~~~~~~

.. automodule:: amocrm.resources._base
   :members:

Сделки
~~~~~~

.. automodule:: amocrm.resources.leads
   :members:

Контакты
~~~~~~~~

.. automodule:: amocrm.resources.contacts
   :members:

Компании
~~~~~~~~

.. automodule:: amocrm.resources.companies
   :members:

Воронки
~~~~~~~

.. automodule:: amocrm.resources.pipelines
   :members:

Задачи
~~~~~~

.. automodule:: amocrm.resources.tasks
   :members:

Модели
------

Общие типы
~~~~~~~~~~

.. automodule:: amocrm.models.common
   :members:

Сделки
~~~~~~

.. automodule:: amocrm.models.leads
   :members:

Контакты
~~~~~~~~

.. automodule:: amocrm.models.contacts
   :members:

Компании
~~~~~~~~

.. automodule:: amocrm.models.companies
   :members:

Воронки и статусы
~~~~~~~~~~~~~~~~~

.. automodule:: amocrm.models.pipelines
   :members:

Задачи
~~~~~~

.. automodule:: amocrm.models.tasks
   :members:
